#
# Cookbook Name:: apt-nginx
# Recipe:: default
#
#  Installs & configures the apt NGINX repostories.  Any attribute supported by
#  the [apt cookbook](https://github.com/chef-cookbooks/apt#parameters) is
#  supported by this cookbook and can be used to override attributes in this
#  cookbook.

# check if platform is supported
platform_family = node['platform_family']
platform = node['platform']
platform_version = node['platform_version']

fail("#{platform_family}/#{platform}/#{platform_version} is not supported by the default recipe") \
  unless platform_family?('debian') &&
         node['apt-nginx']['debian']['supported-codenames']
         .select { |_version, is_included| is_included }
         .keys
         .include?(node['lsb']['codename'])

node['apt-nginx']['repos'].each do |repo, value|
  apt_repository repo do
    # define all attributes even though we are not using them all so that the
    #  values can be passed through to override apt repository definitions

    # Attribute Sources:
    #  https://github.com/opscode-cookbooks/apt
    #  https://github.com/opscode-cookbooks/apt/blob/master/resources/repository.rb

    repo_name value['repo_name']
    uri value['uri']
    distribution value['distribution']
    components value['components']
    arch value['arch']
    trusted value['trusted']
    deb_src value['deb-src']
    keyserver value['keyserver']
    key value['key']
    key_proxy value['key_proxy']
    cookbook value['cookbook']
    cache_rebuild value['cache_rebuild']
  end if value['managed']
end
